#
# spec file for package efibootmgr
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           efibootmgr
VCS: https://src.suse.de/SLFO-pool/efibootmgr#231b9e57374c990421cf3653138909afd2d507f79c1dd301ed17b5398d04ce11
Version:        18
Release:        slfo.1.1_1.2
Summary:        EFI Boot Manager
License:        GPL-2.0-or-later
Group:          System/Boot
URL:            https://github.com/rhinstaller/efibootmgr
Source:         https://github.com/rhboot/efibootmgr/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.bz2
Patch0:         %{name}-delete-multiple.diff
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(efiboot) >= 31
BuildRequires:  pkgconfig(efivar) >= 31
BuildRequires:  pkgconfig(libpci)
BuildRequires:  pkgconfig(popt)
BuildRequires:  pkgconfig(zlib)

%description
The EFI Boot Manager allows the user to edit the Intel Extensible
Firmware Interface (EFI) Boot Manager variables.  Additional
information about the EFI can be found at
<http://developer.intel.com/technology/efi/efi.htm>.

%prep
%autosetup -p1

%build
# removing hotfix function declaration:
# https://github.com/rhboot/efibootmgr/issues/128
sed -e '/extern int efi_set_verbose/d' -i "src/efibootmgr.c"

LOADER="grub.efi"  # default loader
[ "$RPM_ARCH" != ia64 ] || LOADER="elilo.efi"  # except Itanium

case "%{_repository}" in
(openSUSE*)   VENDOR="openSUSE";;
(SLE_11_SP*)  VENDOR="SuSE"     LOADER="elilo.efi";;
(SUSE*|SLE*)  VENDOR="SUSE";;
(*)           VENDOR="linux";;
esac
%make_build CFLAGS="%{optflags} -flto -fPIE -pie" \
	OS_VENDOR="$VENDOR" EFI_LOADER="$LOADER" EFIDIR="$VENDOR"

%install
case "%{_repository}" in
(openSUSE*)   VENDOR="openSUSE";;
(SLE_11_SP*)  VENDOR="SuSE"     LOADER="elilo.efi";;
(SUSE*|SLE*)  VENDOR="SUSE";;
(*)           VENDOR="linux";;
esac
make DESTDIR=%{buildroot} sbindir=%{_sbindir} EFIDIR="$VENDOR" install

%files
%license COPYING
%doc README
%{_sbindir}/efiboot*
%{_mandir}/man8/*.gz

%changelog
* Tue Dec 20 2022 glin@suse.com
- Update to v18
  * fixed the simple run example
  * Restore activation error message in efibootmgr
  * remove-dupes: update error message
  * Fix typo in manual page
  * README: Note efivarfs as the current required kernel module
  * Fix possible read out of bounds in ucs2_to_utf8
  * Add code of conduct
  * Fix help messages
  * Add option for insertion location of new entries
- Rebase efibootmgr-delete-multiple.diff
* Tue Aug  3 2021 info@paolostivanin.com
- Update to v17:  [jsc#SLE-22542]
  * use efivar's logging facility more (more info in -v2 , -v3, etc)
  * Various bug fixes
  * Better -e parsing
  * fix pkg-config invocation for ldflags
  * Make efibootmgr use EFIDIR / efibootmgr.efidir like fwupdate does
  * make --loader default build-time configurable
  * sanitize set_mirror()/get_mirror()
  * Add support for parsing loader options as UCS2
  * GCC 7 fixes
  * Don't use -fshort-wchar since we don't run on EFI machines.
- Drop 0001-Don-t-use-fshort-wchar-when-building-63.patch (upstreamed)
- Drop 0002-Remove-extra-const-keywords-gcc-7-gripes-about.patch
  (upstreamed)
- Drop 0003-Add-support-for-parsing-optional-data-as-ucs2.patch
  (upstreamed)
- Drop MARM-sanitize-set_mirror.diff (upstreamed)
- Drop efibootmgr-derhat.diff (upstreamed)
- Rebase efibootmgr-delete-multiple.diff
* Tue Apr  3 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Sat Jun 10 2017 meissner@suse.com
- forcefully enable PIE
* Fri Mar  3 2017 rw@suse.com
- Update to 14 plus upstream fixes.  [fate#322108]
  (0001-Don-t-use-fshort-wchar-when-building-63.patch,
  0002-Remove-extra-const-keywords-gcc-7-gripes-about.patch,
  0003-Add-support-for-parsing-optional-data-as-ucs2.patch)
- Forward port and refresh SLE patches
  (efibootmgr-derhat.diff, MARM-sanitize-set_mirror.diff
  efibootmgr-delete-multiple.diff)
- Drop upstreamed patches
  (efibootmgr-check-boot-order.diff,
  efibootmgr-fix-efivar-0.24.patch,
  efibootmgr-fix-usage-of-efi_loadopt_path-again.patch,
  MARM-add-m-and-M-options.diff,
  MARM-extend-man-for-M-option.diff,
  MARM-fix-insufficient-validation-check-of-M-option.diff,
  MARM-introduce-man-for-m-and-M-option.diff)
* Thu Feb 16 2017 msuchanek@suse.com
- Build on all archs. There is no reason not to. [boo#1025520]
- Depend on new enough efivar. Build fails otherwise.
* Sat Aug 20 2016 arvidjaar@gmail.com
- add efibootmgr-fix-usage-of-efi_loadopt_path-again.patch - fix
  efibootmgr -v with new efivar (boo#993458)
* Thu Jul 14 2016 rw@suse.com
- Add support for Memory Address Range Mirroring.
  [fate#320999, bsc#987599]
  (add MARM-add-m-and-M-options.diff,
  MARM-fix-insufficient-validation-check-of-M-option.diff,
  MARM-introduce-man-for-m-and-M-option.diff,
  MARM-extend-man-for-M-option.diff,
  MARM-sanitize-set_mirror.diff)
* Wed Jul 13 2016 glin@suse.com
- Add efibootmgr-fix-efivar-0.24.patch fix the compilation errors
  caused by the efivar update
* Tue Sep 15 2015 rw@suse.com
- Properly latch long to short option for delete.  [bsc#945705]
  (efibootmgr-delete-multiple.diff)
* Fri Jul 24 2015 rw@suse.com
- Refresh for SLE12.  [bsc#929677]
  (efibootmgr-gcc-Wall.diff, efibootmgr-delete-multiple.diff)
* Fri Jun 12 2015 mpluskal@suse.com
- Update to 0.12
  * This release is mostly a maintenance release that uses
    libefivar's new library API for creating device paths and load
    options.
  * Also DHCPv4 network boot entries are now something you can
    create without knowing an awful lot about ACPI.
- Refresh patches
  efibootmgr-0.11.0-derhat.diff as efibootmgr-derhat.diff
  efibootmgr-0.11.0-check-boot-order.diff as
  efibootmgr-check-boot-order.diff
- Update project and download url
* Wed Mar 11 2015 rw@suse.com
- Allow disk/partition as selector for delete as well.  [bsc#870211]
  (efibootmgr-delete-multiple.diff)
- Remove version number from patches.
  (add efibootmgr-derhat.diff, efibootmgr-fail-visibly.diff,
  efibootmgr-gcc-Wall.diff, efibootmgr-set_boot_order.diff,
  efibootmgr-write-unique-id-once.diff;
  drop efibootmgr-0.6.0-check-boot-order.diff,
  efibootmgr-0.6.0-delete-by-uuid.diff, efibootmgr-0.6.0-derhat.diff,
  efibootmgr-0.6.0-fail-visibly.diff, efibootmgr-0.6.0-gcc-Wall.diff,
  efibootmgr-0.6.0-set_boot_order.diff,
  efibootmgr-0.6.0-write-unique-id-once.diff)
  Note: this entry reflects obsoleted, SLE-only changes!
* Fri Jan 30 2015 rw@suse.com
- Introduce partition UUID as selector for delete.  [bsc#870211]
  (efibootmgr-0.6.0-delete-by-uuid.diff)
* Mon Dec 22 2014 mpluskal@suse.com
- Enable i586 build
* Fri Oct 31 2014 dmueller@suse.com
- efibootmgr-0.6.0-check-boot-order.diff, efibootmgr-0.6.0-derhat.diff:
  pass source validator check
- switch homepage to https://github.com/vathpela/efibootmgr
* Wed Oct 29 2014 glin@suse.com
- Update version number to 0.11.0
- Rebase patches
  (efibootmgr-0.11.0-derhat.diff,
  efibootmgr-0.11.0-check-boot-order.diff)
- Drop efibootmgr-0.6.0-set_boot_order.diff since the data size of
  the variable is handled properly now
- Drop efibootmgr-0.6.0-fail-visibly.diff since err() and warn()
  are introduced to show more meaningful messages
- Drop upstreamed patch
  (efibootmgr-0.6.0-gcc-Wall.diff,
  efibootmgr-0.6.0-write-unique-id-once.diff)
* Tue Sep  9 2014 schwab@suse.de
- Enable for aarch64 [fate#318444]
* Mon Jul  7 2014 glin@suse.com
- Add efibootmgr-0.6.0-check-boot-order.diff to delete BootOrder
  if there is no more boot option. [bnc#883545]
* Thu Dec 19 2013 rw@suse.com
- Update version number to 0.6.0,
- Integrate SLE11 patches.  [bnc#830784]
  (efibootmgr-0.6.0-fail-visibly.diff,
  efibootmgr-0.6.0-set_boot_order.diff)
- Fix gcc warnings.
  (efibootmgr-0.6.0-gcc-Wall.diff)
- Make default '--loader' build-time configurable.
  (efibootmgr-0.6.0-derhat.diff)
- Don't let '--write-signature' overwrite unique signatures.
  (efibootmgr-0.6.0-write-unique-id-once.diff)
- Drop obsolete patches
  (efibootmgr-0.5.4.diff,
  efibootmgr-0.5.4-catchup.diff,
  efibootmgr-0.5.4-sector-size.diff)
* Wed Mar 27 2013 rw@suse.com
- Print EFI status for failed '--create' as well.  [bnc#811767]
  (efibootmgr-0.5.4-fail-visibly.diff)
* Wed Mar 27 2013 rw@suse.com
- Fix '--bootorder' handling.  [bnc#810899]
  (efibootmgr-0.5.4-set_boot_order.diff)
- Print EFI status in case of failure.  [bnc#811767]
  (efibootmgr-0.5.4-fail-visibly.diff)
* Tue Feb 12 2013 rw@suse.com
- Apply critical upstream fixes
  o for memory leaking variable creation.  [bnc#746324]
  o to improve spec conformance by removing device path padding.
  o to work around broken Apple firmware.
  (efibootmgr-0.5.4-catchup.diff)
- Allow hard disk sector sizes not equal to 512.  [bnc#711830]
  (efibootmgr-0.5.4-sector-size.diff)
* Tue Jun 12 2012 mgorse@suse.com
- Add zlib-devel to BuildRequires
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Wed Oct 15 2008 ro@suse.de
- added ExclusiveArch
* Thu Jul 31 2008 rw@suse.de
- Update to efibootmgr 0.5.4.  [FATE#301882]
* Fri Jan 18 2008 rw@suse.de
- Return non-zero exit code on errors. [#307965, FATE#302608]
* Tue Dec 19 2006 rw@suse.de
- Use '&' instead of '&&' to mask bits. [#219735]
- Fix compilation for STABLE.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov  9 2005 schwab@suse.de
- Update to efibootmgr 0.5.3.
* Mon Sep 19 2005 schwab@suse.de
- Update to efibootmgr 0.5.2.2.
* Wed Aug 10 2005 schwab@suse.de
- Update to efibootmgr 0.5.2 [#102441].
* Tue May 10 2005 schwab@suse.de
- Fix parsing of bus info for network boot entry [#82882].
* Wed Mar  9 2005 schwab@suse.de
- Update to efibootmgr 0.5.1.
* Thu Aug 26 2004 schwab@suse.de
- Update to efibootmgr 0.5.0.
* Wed Jun  9 2004 schwab@suse.de
- Update to efibootmgr 0.5.0-test4.
* Mon May  3 2004 schwab@suse.de
- Update to efibootmgr 0.5.0-test3.
* Fri Sep  5 2003 schwab@suse.de
- Update to efibootmgr 0.4.2.
* Wed Oct 23 2002 schwab@suse.de
- Update to efibootmgr 0.4.1.
* Sun May  5 2002 schwab@suse.de
- Update to efibootmgr 0.4.0.
* Fri Aug 10 2001 schwab@suse.de
- Update to efibootmgr 0.3.4.
* Wed May 23 2001 schwab@suse.de
- Update to efibootmgr 0.3.2.
* Tue May 22 2001 schwab@suse.de
- Fix uninitialized variable.
* Sat May 19 2001 schwab@suse.de
- Initial version 0.3.1.
